mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: Dengcheng Zhu <dengcheng.zhu@mips.com>
To: Paul Burton <paul.burton@mips.com>,
	<linux-kernel@vger.kernel.org>, <trivial@kernel.org>
Cc: Deng-Cheng Zhu <dengcheng.zhu@imgtec.com>,
	Douglas Leung <douglas.leung@imgtec.com>,
	Douglas Leung <douglas.leung@mips.com>,
	"Goran Ferenc" <goran.ferenc@imgtec.com>,
	Goran Ferenc <goran.ferenc@mips.com>,
	"James Cowgill" <james.cowgill@imgtec.com>,
	James Cowgill <james.cowgill@mips.com>,
	Leonid Yegoshin <leonid.yegoshin@imgtec.com>,
	Leonid Yegoshin <leonid.yegoshin@mips.com>,
	Marcin Nowakowski <marcin.nowakowski@imgtec.com>,
	Marcin Nowakowski <marcin.nowakowski@mips.com>,
	Matt Redfearn <matt.redfearn@imgtec.com>,
	Matt Redfearn <matt.redfearn@mips.com>,
	"Zubair Lutfullah Kakakhel" <zubair.kakakhel@imgtec.com>,
	Zubair Lutfullah Kakakhel <zubair.kakakhel@mips.com>
Subject: Re: [PATCH v2] Update MIPS email addresses
Date: Mon, 9 Oct 2017 07:12:19 -0700	[thread overview]
Message-ID: <59DB83C3.2080905@mips.com> (raw)
In-Reply-To: <20171009002406.18300-1-paul.burton@mips.com>

Thanks Paul.

Acked-by: Dengcheng Zhu <dengcheng.zhu@mips.com>


Dengcheng

---------------------------------------------------------------------------

*From:* Paul Burton <mailto:paul.burton@mips.com>
*Sent:* Sunday, October 08, 2017 5:24PM
*To:* Linux-kernel <mailto:linux-kernel@vger.kernel.org>, Trivial 
<mailto:trivial@kernel.org>
*Cc:* Paul Burton <mailto:paul.burton@mips.com>, Deng-cheng Zhu 
<mailto:dengcheng.zhu@imgtec.com>, Deng-cheng Zhu 
<mailto:dengcheng.zhu@mips.com>, Douglas Leung 
<mailto:douglas.leung@imgtec.com>, Douglas Leung 
<mailto:douglas.leung@mips.com>, Goran Ferenc 
<mailto:goran.ferenc@imgtec.com>, Goran Ferenc 
<mailto:goran.ferenc@mips.com>, James Cowgill 
<mailto:james.cowgill@imgtec.com>, James Cowgill 
<mailto:james.cowgill@mips.com>, Leonid Yegoshin 
<mailto:leonid.yegoshin@imgtec.com>, Leonid Yegoshin 
<mailto:leonid.yegoshin@mips.com>, Marcin Nowakowski 
<mailto:marcin.nowakowski@imgtec.com>, Marcin Nowakowski 
<mailto:marcin.nowakowski@mips.com>, Matt Redfearn 
<mailto:matt.redfearn@imgtec.com>, Matt Redfearn 
<mailto:matt.redfearn@mips.com>, Zubair Lutfullah Kakakhel 
<mailto:zubair.kakakhel@imgtec.com>, Zubair Lutfullah Kakakhel 
<mailto:zubair.kakakhel@mips.com>
*Subject:* [PATCH v2] Update MIPS email addresses

MIPS will soon not be a part of Imagination Technologies, and as such
many @imgtec.com email addresses will no longer be valid. This patch
updates the addresses for all those who:

  - Have 10 or more patches in mainline authored using an @imgtec.com
    email address, or any patches dated within the past year.

  - Are still with Imagination but leaving as part of the MIPS business
    unit, as determined from an internal email address list.

  - Haven't already updated their email address (ie. JamesH) or expressed
    a desire to be excluded (ie. Maciej).

New addresses are of the form firstname.lastname@mips.com, and all
verified against an internal email address list. An entry is added to
.mailmap for each person such that get_maintainer.pl will report the new
addresses rather than @imgtec.com addresses which will soon be dead.

Instances of the affected addresses throughout the tree are then
mechanically replaced with the new @mips.com address.

Signed-off-by: Paul Burton <paul.burton@mips.com>
Cc: Deng-Cheng Zhu <dengcheng.zhu@imgtec.com>
Cc: Deng-Cheng Zhu <dengcheng.zhu@mips.com>
Cc: Douglas Leung <douglas.leung@imgtec.com>
Cc: Douglas Leung <douglas.leung@mips.com>
Cc: Goran Ferenc <goran.ferenc@imgtec.com>
Cc: Goran Ferenc <goran.ferenc@mips.com>
Cc: James Cowgill <james.cowgill@imgtec.com>
Cc: James Cowgill <james.cowgill@mips.com>
Cc: Leonid Yegoshin <leonid.yegoshin@imgtec.com>
Cc: Leonid Yegoshin <leonid.yegoshin@mips.com>
Cc: Marcin Nowakowski <marcin.nowakowski@imgtec.com>
Cc: Marcin Nowakowski <marcin.nowakowski@mips.com>
Cc: Matt Redfearn <matt.redfearn@imgtec.com>
Cc: Matt Redfearn <matt.redfearn@mips.com>
Cc: Zubair Lutfullah Kakakhel <zubair.kakakhel@imgtec.com>
Cc: Zubair Lutfullah Kakakhel <zubair.kakakhel@mips.com>
Cc: linux-kernel@vger.kernel.org
Cc: trivial@kernel.org
---
Changes in v2:
- Remove Maciej at his request.
- Cc @imgtec.com addresses too.
- Update authorship to my @mips.com address.

If others affected can chime in with acks or otherwise please do.
---
  .mailmap                                         | 9 +++++++++
  Documentation/ABI/testing/sysfs-class-remoteproc | 4 ++--
  MAINTAINERS                                      | 8 ++++----
  arch/mips/generic/Makefile                       | 2 +-
  arch/mips/generic/Platform                       | 2 +-
  arch/mips/generic/board-sead3.c                  | 2 +-
  arch/mips/generic/init.c                         | 2 +-
  arch/mips/generic/irq.c                          | 2 +-
  arch/mips/generic/kexec.c                        | 2 +-
  arch/mips/generic/proc.c                         | 2 +-
  arch/mips/generic/yamon-dt.c                     | 2 +-
  arch/mips/include/asm/dsemul.h                   | 2 +-
  arch/mips/include/asm/maar.h                     | 2 +-
  arch/mips/include/asm/mach-malta/malta-dtshim.h  | 2 +-
  arch/mips/include/asm/mach-malta/malta-pm.h      | 2 +-
  arch/mips/include/asm/mach-xilfpga/irq.h         | 2 +-
  arch/mips/include/asm/machine.h                  | 2 +-
  arch/mips/include/asm/mips-cm.h                  | 2 +-
  arch/mips/include/asm/mips-cpc.h                 | 2 +-
  arch/mips/include/asm/mips-cps.h                 | 2 +-
  arch/mips/include/asm/mips-gic.h                 | 2 +-
  arch/mips/include/asm/msa.h                      | 2 +-
  arch/mips/include/asm/pm-cps.h                   | 2 +-
  arch/mips/include/asm/smp-cps.h                  | 2 +-
  arch/mips/include/asm/yamon-dt.h                 | 2 +-
  arch/mips/kernel/cmpxchg.c                       | 2 +-
  arch/mips/kernel/cps-vec-ns16550.S               | 2 +-
  arch/mips/kernel/cps-vec.S                       | 2 +-
  arch/mips/kernel/elf.c                           | 2 +-
  arch/mips/kernel/mips-cm.c                       | 2 +-
  arch/mips/kernel/mips-cpc.c                      | 2 +-
  arch/mips/kernel/mips-r2-to-r6-emul.c            | 2 +-
  arch/mips/kernel/pm-cps.c                        | 2 +-
  arch/mips/kernel/probes-common.h                 | 2 +-
  arch/mips/kernel/relocate.c                      | 2 +-
  arch/mips/kernel/smp-cps.c                       | 2 +-
  arch/mips/mm/sc-debugfs.c                        | 2 +-
  arch/mips/mti-malta/malta-dt.c                   | 2 +-
  arch/mips/mti-malta/malta-dtshim.c               | 2 +-
  arch/mips/mti-malta/malta-pm.c                   | 2 +-
  arch/mips/pci/pci-generic.c                      | 2 +-
  arch/mips/tools/generic-board-config.sh          | 2 +-
  arch/mips/xilfpga/init.c                         | 2 +-
  arch/mips/xilfpga/intc.c                         | 2 +-
  arch/mips/xilfpga/time.c                         | 2 +-
  drivers/auxdisplay/img-ascii-lcd.c               | 2 +-
  drivers/clk/imgtec/clk-boston.c                  | 2 +-
  drivers/clk/ingenic/cgu.c                        | 2 +-
  drivers/clk/ingenic/cgu.h                        | 2 +-
  drivers/clk/ingenic/jz4740-cgu.c                 | 2 +-
  drivers/clk/ingenic/jz4780-cgu.c                 | 2 +-
  drivers/cpuidle/cpuidle-cps.c                    | 2 +-
  drivers/power/reset/piix4-poweroff.c             | 4 ++--
  53 files changed, 66 insertions(+), 57 deletions(-)

diff --git a/.mailmap b/.mailmap
index c7b10caecc4e..c51e81d652f1 100644
--- a/.mailmap
+++ b/.mailmap
@@ -43,9 +43,11 @@ Corey Minyard <minyard@acm.org>
  Damian Hobson-Garcia <dhobsong@igel.co.jp>
  David Brownell <david-b@pacbell.net>
  David Woodhouse <dwmw2@shinybook.infradead.org>
+Deng-Cheng Zhu <dengcheng.zhu@mips.com> <dengcheng.zhu@imgtec.com>
  Dmitry Eremin-Solenikov <dbaryshkov@gmail.com>
  Domen Puncer <domen@coderock.org>
  Douglas Gilbert <dougg@torque.net>
+Douglas Leung <douglas.leung@mips.com> <douglas.leung@imgtec.com>
  Ed L. Cashin <ecashin@coraid.com>
  Evgeniy Polyakov <johnpol@2ka.mipt.ru>
  Felipe W Damasio <felipewd@terra.com.br>
@@ -57,6 +59,7 @@ Frank Rowand <frowand.list@gmail.com> <frowand@mvista.com>
  Frank Rowand <frowand.list@gmail.com> <frank.rowand@am.sony.com>
  Frank Rowand <frowand.list@gmail.com> <frank.rowand@sonymobile.com>
  Frank Zago <fzago@systemfabricworks.com>
+Goran Ferenc <goran.ferenc@mips.com> <goran.ferenc@imgtec.com>
  Greg Kroah-Hartman <greg@echidna.(none)>
  Greg Kroah-Hartman <gregkh@suse.de>
  Greg Kroah-Hartman <greg@kroah.com>
@@ -67,6 +70,7 @@ Herbert Xu <herbert@gondor.apana.org.au>
  Jacob Shin <Jacob.Shin@amd.com>
  James Bottomley <jejb@mulgrave.(none)>
  James Bottomley <jejb@titanic.il.steeleye.com>
+James Cowgill <james.cowgill@mips.com> <james.cowgill@imgtec.com>
  James E Wilson <wilson@specifix.com>
  James Hogan <jhogan@kernel.org> <james.hogan@imgtec.com>
  James Hogan <jhogan@kernel.org> <james@albanarts.com>
@@ -97,9 +101,11 @@ Krzysztof Kozlowski <krzk@kernel.org> <k.kozlowski@samsung.com>
  Krzysztof Kozlowski <krzk@kernel.org> <k.kozlowski.k@gmail.com>
  Kuninori Morimoto <kuninori.morimoto.gx@renesas.com>
  Leonid I Ananiev <leonid.i.ananiev@intel.com>
+Leonid Yegoshin <leonid.yegoshin@mips.com> <leonid.yegoshin@imgtec.com>
  Linas Vepstas <linas@austin.ibm.com>
  Linus Lüssing <linus.luessing@c0d3.blue> <linus.luessing@web.de>
  Linus Lüssing <linus.luessing@c0d3.blue> <linus.luessing@ascom.ch>
+Marcin Nowakowski <marcin.nowakowski@mips.com> <marcin.nowakowski@imgtec.com>
  Mark Brown <broonie@sirena.org.uk>
  Martin Kepplinger <martink@posteo.de> <martin.kepplinger@theobroma-systems.com>
  Martin Kepplinger <martink@posteo.de> <martin.kepplinger@ginzinger.com>
@@ -114,6 +120,7 @@ Mauro Carvalho Chehab <mchehab@kernel.org> <mchehab@s-opensource.com>
  Matt Ranostay <mranostay@gmail.com> Matthew Ranostay <mranostay@embeddedalley.com>
  Matt Ranostay <mranostay@gmail.com> <matt.ranostay@intel.com>
  Matt Ranostay <matt.ranostay@konsulko.com> <matt@ranostay.consulting>
+Matt Redfearn <matt.redfearn@mips.com> <matt.redfearn@imgtec.com>
  Mayuresh Janorkar <mayur@ti.com>
  Michael Buesch <m@bues.ch>
  Michel Dänzer <michel@tungstengraphics.com>
@@ -127,6 +134,7 @@ Mythri P K <mythripk@ti.com>
  Nguyen Anh Quynh <aquynh@gmail.com>
  Paolo 'Blaisorblade' Giarrusso <blaisorblade@yahoo.it>
  Patrick Mochel <mochel@digitalimplant.org>
+Paul Burton <paul.burton@mips.com> <paul.burton@imgtec.com>
  Peter A Jonsson <pj@ludd.ltu.se>
  Peter Oruba <peter@oruba.de>
  Peter Oruba <peter.oruba@amd.com>
@@ -180,5 +188,6 @@ Vladimir Davydov <vdavydov.dev@gmail.com> <vdavydov@parallels.com>
  Takashi YOSHII <takashi.yoshii.zj@renesas.com>
  Yakir Yang <kuankuan.y@gmail.com> <ykk@rock-chips.com>
  Yusuke Goda <goda.yusuke@renesas.com>
+Zubair Lutfullah Kakakhel <zubair.kakakhel@mips.com> <zubair.kakakhel@imgtec.com>
  Gustavo Padovan <gustavo@las.ic.unicamp.br>
  Gustavo Padovan <padovan@profusion.mobi>
diff --git a/Documentation/ABI/testing/sysfs-class-remoteproc b/Documentation/ABI/testing/sysfs-class-remoteproc
index d188afebc8ba..c3afe9fab646 100644
--- a/Documentation/ABI/testing/sysfs-class-remoteproc
+++ b/Documentation/ABI/testing/sysfs-class-remoteproc
@@ -1,6 +1,6 @@
  What:		/sys/class/remoteproc/.../firmware
  Date:		October 2016
-Contact:	Matt Redfearn <matt.redfearn@imgtec.com>
+Contact:	Matt Redfearn <matt.redfearn@mips.com>
  Description:	Remote processor firmware
  
  		Reports the name of the firmware currently loaded to the
@@ -11,7 +11,7 @@ Description:	Remote processor firmware
  
  What:		/sys/class/remoteproc/.../state
  Date:		October 2016
-Contact:	Matt Redfearn <matt.redfearn@imgtec.com>
+Contact:	Matt Redfearn <matt.redfearn@mips.com>
  Description:	Remote processor state
  
  		Reports the state of the remote processor, which will be one of:
diff --git a/MAINTAINERS b/MAINTAINERS
index cc42c838ab4f..0163059de67d 100644
--- a/MAINTAINERS
+++ b/MAINTAINERS
@@ -6732,7 +6732,7 @@ S:	Maintained
  F:	drivers/usb/atm/ueagle-atm.c
  
  IMGTEC ASCII LCD DRIVER
-M:	Paul Burton <paul.burton@imgtec.com>
+M:	Paul Burton <paul.burton@mips.com>
  S:	Maintained
  F:	Documentation/devicetree/bindings/auxdisplay/img-ascii-lcd.txt
  F:	drivers/auxdisplay/img-ascii-lcd.c
@@ -6789,7 +6789,7 @@ F:	include/uapi/rdma/
  F:	include/rdma/
  
  INGENIC JZ4780 DMA Driver
-M:	Zubair Lutfullah Kakakhel <Zubair.Kakakhel@imgtec.com>
+M:	Zubair Lutfullah Kakakhel <zubair.kakakhel@mips.com>
  S:	Maintained
  F:	drivers/dma/dma-jz4780.c
  
@@ -8992,7 +8992,7 @@ F:	Documentation/mips/
  F:	arch/mips/
  
  MIPS BOSTON DEVELOPMENT BOARD
-M:	Paul Burton <paul.burton@imgtec.com>
+M:	Paul Burton <paul.burton@mips.com>
  L:	linux-mips@linux-mips.org
  S:	Maintained
  F:	Documentation/devicetree/bindings/clock/img,boston-clock.txt
@@ -9002,7 +9002,7 @@ F:	drivers/clk/imgtec/clk-boston.c
  F:	include/dt-bindings/clock/boston-clock.h
  
  MIPS GENERIC PLATFORM
-M:	Paul Burton <paul.burton@imgtec.com>
+M:	Paul Burton <paul.burton@mips.com>
  L:	linux-mips@linux-mips.org
  S:	Supported
  F:	arch/mips/generic/
diff --git a/arch/mips/generic/Makefile b/arch/mips/generic/Makefile
index 56b3ea565ed9..874967363dbb 100644
--- a/arch/mips/generic/Makefile
+++ b/arch/mips/generic/Makefile
@@ -1,6 +1,6 @@
  #
  # Copyright (C) 2016 Imagination Technologies
-# Author: Paul Burton <paul.burton@imgtec.com>
+# Author: Paul Burton <paul.burton@mips.com>
  #
  # This program is free software; you can redistribute it and/or modify it
  # under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/generic/Platform b/arch/mips/generic/Platform
index f5312dfa8184..b51432dd10b6 100644
--- a/arch/mips/generic/Platform
+++ b/arch/mips/generic/Platform
@@ -1,6 +1,6 @@
  #
  # Copyright (C) 2016 Imagination Technologies
-# Author: Paul Burton <paul.burton@imgtec.com>
+# Author: Paul Burton <paul.burton@mips.com>
  #
  # This program is free software; you can redistribute it and/or modify it
  # under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/generic/board-sead3.c b/arch/mips/generic/board-sead3.c
index f109a6b9fdd0..10cf93d97346 100644
--- a/arch/mips/generic/board-sead3.c
+++ b/arch/mips/generic/board-sead3.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/generic/init.c b/arch/mips/generic/init.c
index 15a7fb8e2a2e..cf409ba358a1 100644
--- a/arch/mips/generic/init.c
+++ b/arch/mips/generic/init.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/generic/irq.c b/arch/mips/generic/irq.c
index 5322d09dd51b..394f8161e462 100644
--- a/arch/mips/generic/irq.c
+++ b/arch/mips/generic/irq.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/generic/kexec.c b/arch/mips/generic/kexec.c
index e9fb735299e3..1ca409f58929 100644
--- a/arch/mips/generic/kexec.c
+++ b/arch/mips/generic/kexec.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
- * Author: Marcin Nowakowski <marcin.nowakowski@imgtec.com>
+ * Author: Marcin Nowakowski <marcin.nowakowski@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/generic/proc.c b/arch/mips/generic/proc.c
index 42b33250a4a2..199fb2cc57ee 100644
--- a/arch/mips/generic/proc.c
+++ b/arch/mips/generic/proc.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/generic/yamon-dt.c b/arch/mips/generic/yamon-dt.c
index 6077bca9b364..b408dac722ac 100644
--- a/arch/mips/generic/yamon-dt.c
+++ b/arch/mips/generic/yamon-dt.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/dsemul.h b/arch/mips/include/asm/dsemul.h
index a6e067801f23..b47a97527673 100644
--- a/arch/mips/include/asm/dsemul.h
+++ b/arch/mips/include/asm/dsemul.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/maar.h b/arch/mips/include/asm/maar.h
index e10f78befbd9..1e0da80bba13 100644
--- a/arch/mips/include/asm/maar.h
+++ b/arch/mips/include/asm/maar.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2014 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/mach-malta/malta-dtshim.h b/arch/mips/include/asm/mach-malta/malta-dtshim.h
index cfd777663c64..d696a7598ea7 100644
--- a/arch/mips/include/asm/mach-malta/malta-dtshim.h
+++ b/arch/mips/include/asm/mach-malta/malta-dtshim.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2015 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/mach-malta/malta-pm.h b/arch/mips/include/asm/mach-malta/malta-pm.h
index c2c2e201013d..347b53dbc88f 100644
--- a/arch/mips/include/asm/mach-malta/malta-pm.h
+++ b/arch/mips/include/asm/mach-malta/malta-pm.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2014 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/mach-xilfpga/irq.h b/arch/mips/include/asm/mach-xilfpga/irq.h
index 0132a5b91f57..8c6a51dda2a7 100644
--- a/arch/mips/include/asm/mach-xilfpga/irq.h
+++ b/arch/mips/include/asm/mach-xilfpga/irq.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2015 Imagination Technologies
- * Author: Zubair Lutfullah Kakakhel <Zubair.Kakakhel@imgtec.com>
+ * Author: Zubair Lutfullah Kakakhel <zubair.kakakhel@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/machine.h b/arch/mips/include/asm/machine.h
index ecb6c7335484..e0d9b373d415 100644
--- a/arch/mips/include/asm/machine.h
+++ b/arch/mips/include/asm/machine.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/mips-cm.h b/arch/mips/include/asm/mips-cm.h
index f6231b91b724..3708b8ccc0b4 100644
--- a/arch/mips/include/asm/mips-cm.h
+++ b/arch/mips/include/asm/mips-cm.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2013 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/mips-cpc.h b/arch/mips/include/asm/mips-cpc.h
index f885051a8378..b55e335cfba4 100644
--- a/arch/mips/include/asm/mips-cpc.h
+++ b/arch/mips/include/asm/mips-cpc.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2013 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/mips-cps.h b/arch/mips/include/asm/mips-cps.h
index bf02b5070a98..8ad4a85eed0c 100644
--- a/arch/mips/include/asm/mips-cps.h
+++ b/arch/mips/include/asm/mips-cps.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2017 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/mips-gic.h b/arch/mips/include/asm/mips-gic.h
index a2badf572632..558059a8f218 100644
--- a/arch/mips/include/asm/mips-gic.h
+++ b/arch/mips/include/asm/mips-gic.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2017 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/msa.h b/arch/mips/include/asm/msa.h
index 8967b475ab10..b1845102f8f9 100644
--- a/arch/mips/include/asm/msa.h
+++ b/arch/mips/include/asm/msa.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2013 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/pm-cps.h b/arch/mips/include/asm/pm-cps.h
index 89d58d80b77b..bb0616967342 100644
--- a/arch/mips/include/asm/pm-cps.h
+++ b/arch/mips/include/asm/pm-cps.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2014 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/smp-cps.h b/arch/mips/include/asm/smp-cps.h
index 2ae1f61a4a95..16b4ee3feb98 100644
--- a/arch/mips/include/asm/smp-cps.h
+++ b/arch/mips/include/asm/smp-cps.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2013 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/include/asm/yamon-dt.h b/arch/mips/include/asm/yamon-dt.h
index 485cfe3e45e1..10a073e6877a 100644
--- a/arch/mips/include/asm/yamon-dt.h
+++ b/arch/mips/include/asm/yamon-dt.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/kernel/cmpxchg.c b/arch/mips/kernel/cmpxchg.c
index 7730f1d3434f..0b9535bc2c53 100644
--- a/arch/mips/kernel/cmpxchg.c
+++ b/arch/mips/kernel/cmpxchg.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2017 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/kernel/cps-vec-ns16550.S b/arch/mips/kernel/cps-vec-ns16550.S
index 6d246ad05638..b37af23a5358 100644
--- a/arch/mips/kernel/cps-vec-ns16550.S
+++ b/arch/mips/kernel/cps-vec-ns16550.S
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2015 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/kernel/cps-vec.S b/arch/mips/kernel/cps-vec.S
index d173b49f212d..c7ed26029cbb 100644
--- a/arch/mips/kernel/cps-vec.S
+++ b/arch/mips/kernel/cps-vec.S
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2013 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/kernel/elf.c b/arch/mips/kernel/elf.c
index 0828d6d963b7..731325a61a78 100644
--- a/arch/mips/kernel/elf.c
+++ b/arch/mips/kernel/elf.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2014 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/kernel/mips-cm.c b/arch/mips/kernel/mips-cm.c
index e91c8c4e2eb5..dd5567b1e305 100644
--- a/arch/mips/kernel/mips-cm.c
+++ b/arch/mips/kernel/mips-cm.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2013 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/kernel/mips-cpc.c b/arch/mips/kernel/mips-cpc.c
index f66b05ebf637..19c88d770054 100644
--- a/arch/mips/kernel/mips-cpc.c
+++ b/arch/mips/kernel/mips-cpc.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2013 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/kernel/mips-r2-to-r6-emul.c b/arch/mips/kernel/mips-r2-to-r6-emul.c
index eb18b186e858..42f3dd4eff9a 100644
--- a/arch/mips/kernel/mips-r2-to-r6-emul.c
+++ b/arch/mips/kernel/mips-r2-to-r6-emul.c
@@ -4,7 +4,7 @@
   * for more details.
   *
   * Copyright (c) 2014 Imagination Technologies Ltd.
- * Author: Leonid Yegoshin <Leonid.Yegoshin@imgtec.com>
+ * Author: Leonid Yegoshin <leonid.yegoshin@mips.com>
   * Author: Markos Chandras <markos.chandras@imgtec.com>
   *
   *      MIPS R2 user space instruction emulator for MIPS R6
diff --git a/arch/mips/kernel/pm-cps.c b/arch/mips/kernel/pm-cps.c
index 4655017f2377..9dd624c2fe56 100644
--- a/arch/mips/kernel/pm-cps.c
+++ b/arch/mips/kernel/pm-cps.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2014 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/kernel/probes-common.h b/arch/mips/kernel/probes-common.h
index dd08e41134b6..d2bf77b18822 100644
--- a/arch/mips/kernel/probes-common.h
+++ b/arch/mips/kernel/probes-common.h
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
- * Author: Marcin Nowakowski <marcin.nowakowski@imgtec.com>
+ * Author: Marcin Nowakowski <marcin.nowakowski@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/kernel/relocate.c b/arch/mips/kernel/relocate.c
index 2d1a0c438771..cbf4cc0b0b6c 100644
--- a/arch/mips/kernel/relocate.c
+++ b/arch/mips/kernel/relocate.c
@@ -6,7 +6,7 @@
   * Support for Kernel relocation at boot time
   *
   * Copyright (C) 2015, Imagination Technologies Ltd.
- * Authors: Matt Redfearn (matt.redfearn@imgtec.com)
+ * Authors: Matt Redfearn (matt.redfearn@mips.com)
   */
  #include <asm/bootinfo.h>
  #include <asm/cacheflush.h>
diff --git a/arch/mips/kernel/smp-cps.c b/arch/mips/kernel/smp-cps.c
index 0063122c85da..7d6af41888e8 100644
--- a/arch/mips/kernel/smp-cps.c
+++ b/arch/mips/kernel/smp-cps.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2013 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/mm/sc-debugfs.c b/arch/mips/mm/sc-debugfs.c
index 7e945e310b44..2e2132d3f5c7 100644
--- a/arch/mips/mm/sc-debugfs.c
+++ b/arch/mips/mm/sc-debugfs.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2015 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/mti-malta/malta-dt.c b/arch/mips/mti-malta/malta-dt.c
index 4822943100f3..b397117033aa 100644
--- a/arch/mips/mti-malta/malta-dt.c
+++ b/arch/mips/mti-malta/malta-dt.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2015 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/mti-malta/malta-dtshim.c b/arch/mips/mti-malta/malta-dtshim.c
index a6699c15277d..7859b6e49863 100644
--- a/arch/mips/mti-malta/malta-dtshim.c
+++ b/arch/mips/mti-malta/malta-dtshim.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2015 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/mti-malta/malta-pm.c b/arch/mips/mti-malta/malta-pm.c
index c1e456c01a44..efbd659fb602 100644
--- a/arch/mips/mti-malta/malta-pm.c
+++ b/arch/mips/mti-malta/malta-pm.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2014 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/pci/pci-generic.c b/arch/mips/pci/pci-generic.c
index dce304dc3d62..676348164027 100644
--- a/arch/mips/pci/pci-generic.c
+++ b/arch/mips/pci/pci-generic.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * pcibios_align_resource taken from arch/arm/kernel/bios32.c.
   *
diff --git a/arch/mips/tools/generic-board-config.sh b/arch/mips/tools/generic-board-config.sh
index 5c4f93687039..82b09af5c144 100755
--- a/arch/mips/tools/generic-board-config.sh
+++ b/arch/mips/tools/generic-board-config.sh
@@ -1,7 +1,7 @@
  #!/bin/sh
  #
  # Copyright (C) 2017 Imagination Technologies
-# Author: Paul Burton <paul.burton@imgtec.com>
+# Author: Paul Burton <paul.burton@mips.com>
  #
  # This program is free software; you can redistribute it and/or modify it
  # under the terms of the GNU General Public License as published by the
diff --git a/arch/mips/xilfpga/init.c b/arch/mips/xilfpga/init.c
index 602e384a26a2..1dc7f2f9045b 100644
--- a/arch/mips/xilfpga/init.c
+++ b/arch/mips/xilfpga/init.c
@@ -2,7 +2,7 @@
   * Xilfpga platform setup
   *
   * Copyright (C) 2015 Imagination Technologies
- * Author: Zubair Lutfullah Kakakhel <Zubair.Kakakhel@imgtec.com>
+ * Author: Zubair Lutfullah Kakakhel <zubair.kakakhel@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms and conditions of the GNU General Public License,
diff --git a/arch/mips/xilfpga/intc.c b/arch/mips/xilfpga/intc.c
index a127cca3ae8c..539bcccb9acc 100644
--- a/arch/mips/xilfpga/intc.c
+++ b/arch/mips/xilfpga/intc.c
@@ -2,7 +2,7 @@
   * Xilfpga interrupt controller setup
   *
   * Copyright (C) 2015 Imagination Technologies
- * Author: Zubair Lutfullah Kakakhel <Zubair.Kakakhel@imgtec.com>
+ * Author: Zubair Lutfullah Kakakhel <zubair.kakakhel@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms and conditions of the GNU General Public License,
diff --git a/arch/mips/xilfpga/time.c b/arch/mips/xilfpga/time.c
index 36f3f1870ee2..461c02f96127 100644
--- a/arch/mips/xilfpga/time.c
+++ b/arch/mips/xilfpga/time.c
@@ -2,7 +2,7 @@
   * Xilfpga clocksource/timer setup
   *
   * Copyright (C) 2015 Imagination Technologies
- * Author: Zubair Lutfullah Kakakhel <Zubair.Kakakhel@imgtec.com>
+ * Author: Zubair Lutfullah Kakakhel <zubair.kakakhel@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms and conditions of the GNU General Public License,
diff --git a/drivers/auxdisplay/img-ascii-lcd.c b/drivers/auxdisplay/img-ascii-lcd.c
index 25306fa27251..a9020f82eea7 100644
--- a/drivers/auxdisplay/img-ascii-lcd.c
+++ b/drivers/auxdisplay/img-ascii-lcd.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/drivers/clk/imgtec/clk-boston.c b/drivers/clk/imgtec/clk-boston.c
index f18f10351785..15af423cc0c9 100644
--- a/drivers/clk/imgtec/clk-boston.c
+++ b/drivers/clk/imgtec/clk-boston.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016-2017 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/drivers/clk/ingenic/cgu.c b/drivers/clk/ingenic/cgu.c
index e8248f9185f7..ab393637f7b0 100644
--- a/drivers/clk/ingenic/cgu.c
+++ b/drivers/clk/ingenic/cgu.c
@@ -2,7 +2,7 @@
   * Ingenic SoC CGU driver
   *
   * Copyright (c) 2013-2015 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
diff --git a/drivers/clk/ingenic/cgu.h b/drivers/clk/ingenic/cgu.h
index 09700b2c555d..e78b586536ea 100644
--- a/drivers/clk/ingenic/cgu.h
+++ b/drivers/clk/ingenic/cgu.h
@@ -2,7 +2,7 @@
   * Ingenic SoC CGU driver
   *
   * Copyright (c) 2013-2015 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
diff --git a/drivers/clk/ingenic/jz4740-cgu.c b/drivers/clk/ingenic/jz4740-cgu.c
index 510fe7e0c8f1..32fcc75f6f77 100644
--- a/drivers/clk/ingenic/jz4740-cgu.c
+++ b/drivers/clk/ingenic/jz4740-cgu.c
@@ -2,7 +2,7 @@
   * Ingenic JZ4740 SoC CGU driver
   *
   * Copyright (c) 2015 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
diff --git a/drivers/clk/ingenic/jz4780-cgu.c b/drivers/clk/ingenic/jz4780-cgu.c
index b35d6d9dd5aa..ac3585ed8228 100644
--- a/drivers/clk/ingenic/jz4780-cgu.c
+++ b/drivers/clk/ingenic/jz4780-cgu.c
@@ -2,7 +2,7 @@
   * Ingenic JZ4780 SoC CGU driver
   *
   * Copyright (c) 2013-2015 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
diff --git a/drivers/cpuidle/cpuidle-cps.c b/drivers/cpuidle/cpuidle-cps.c
index 72b5e47286b4..dac8ff6391fa 100644
--- a/drivers/cpuidle/cpuidle-cps.c
+++ b/drivers/cpuidle/cpuidle-cps.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2014 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
diff --git a/drivers/power/reset/piix4-poweroff.c b/drivers/power/reset/piix4-poweroff.c
index bacfc95783f0..20ce3ff5e039 100644
--- a/drivers/power/reset/piix4-poweroff.c
+++ b/drivers/power/reset/piix4-poweroff.c
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
  * Author: Paul Burton <paul.burton@imgtec.com>
   *
   * This program is free software; you can redistribute it and/or modify it
   * under the terms of the GNU General Public License as published by the
@@ -109,5 +109,5 @@ static struct pci_driver piix4_poweroff_driver = {
  };
  
  module_pci_driver(piix4_poweroff_driver);
-MODULE_AUTHOR("Paul Burton <paul.burton@imgtec.com>");
+MODULE_AUTHOR("Paul Burton <paul.burton@mips.com>");
  MODULE_LICENSE("GPL");

      parent reply	other threads:[~2017-10-09 14:22 UTC|newest]
@@ -1,6 +1,6 @@
  /*
   * Copyright (C) 2016 Imagination Technologies
- * Author: Paul Burton <paul.burton@imgtec.com>
+ * Author: Paul Burton <paul.burton@mips.com>
   *
   * This program is free software; you can redistribute it and/or modify it

Thread overview: 5+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2017-10-06 16:10 [PATCH] " Paul Burton
2017-10-08 20:59 ` Maciej W. Rozycki
2017-10-09  0:24 ` [PATCH v2] " Paul Burton
2017-10-09  9:55   ` Matt Redfearn
2017-10-09 14:12   ` Dengcheng Zhu [this message]

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=59DB83C3.2080905@mips.com \
    --to=dengcheng.zhu@mips.com \
    --cc=dengcheng.zhu@imgtec.com \
    --cc=douglas.leung@imgtec.com \
    --cc=douglas.leung@mips.com \
    --cc=goran.ferenc@imgtec.com \
    --cc=goran.ferenc@mips.com \
    --cc=james.cowgill@imgtec.com \
    --cc=james.cowgill@mips.com \
    --cc=leonid.yegoshin@imgtec.com \
    --cc=leonid.yegoshin@mips.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=marcin.nowakowski@imgtec.com \
    --cc=marcin.nowakowski@mips.com \
    --cc=matt.redfearn@imgtec.com \
    --cc=matt.redfearn@mips.com \
    --cc=paul.burton@mips.com \
    --cc=trivial@kernel.org \
    --cc=zubair.kakakhel@imgtec.com \
    --cc=zubair.kakakhel@mips.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

Powered by JetHome